RapidPro Dash Library
=====================

[![Build Status](https://travis-ci.org/rapidpro/dash.svg?branch=master)](https://travis-ci.org/rapidpro/dash)
[![Coverage Status](https://coveralls.io/repos/github/rapidpro/dash/badge.svg?branch=master)](https://coveralls.io/github/rapidpro/dash)
[![PyPI Release](https://img.shields.io/pypi/v/rapidpro-dash.svg)](https://pypi.python.org/pypi/rapidpro-dash/)

Support library for building dashboards applications for [RapidPro](https://github.com/rapidpro/rapidpro).
